<?php

# This file controls the entire application. All of the different aspects,
# all of the different functions, etc., are accessible via this navigation panel

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<body>

<h1 align="center">WebInvoicer</h1>

<h3>Company Tasks</h3>
<ul>
  <li><a href="choosecompany.php" target="DISPLAY">View all companies</a>
  <li><a href="editcompany.php" target="DISPLAY">Add a new company</a>
</ul>

<h3>Invoice Tasks</h3>
<ul>
  <li><form action="printinvoice.php" target="DISPLAY" method="POST" enctype="text">
    <b>Print an invoice</b><br>
    <input type="text" name="transaction_id" size=11>
    <input type=submit value="Print">
  </form>
  <li><a href="listunpaidinvoices.php" target="DISPLAY">List unpaid invoices</a>
</ul>

<h3>Reporting Tasks</h3>
<ul>
  <li><a href="reports.php" target="DISPLAY">View reports</a>
</ul>

</body>
</html>

