<?php

# This file sets up the frames which organizes the application.
# NOTE: if you don't like frames, then adjust the application to your liking.
#
# However, using frames enables you to do stuff like display an invoice
# and print only that frame, thus losing all of the extra stuff (navigation, etc.)
# that you don't want to be sending to your clients.

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>WebInvoicer 0.6, by Joey Kelly</title>
</head>

<frameset COLS="20%,80%" FRAMEBORDER="0" FRAMESPACING="0" BORDER="0">
<frame NAME="NAVPANEL" SRC="navpanel.php">
<frame NAME="DISPLAY" SRC="welcome.php">
</frameset>

</html> 
