<?php
print "<b>standardinclude.inc is being included</b><br>\n";
# This is our boilerplate include which enables and defines our entire application.
# Anything we have to type into the head of each file ought to be placed here instead.

# Here we define the path to the directory containing our settings
# If you move the settings directory, please make the change in settingspath.inc
include ('settingspath.inc');

# here we read in up our config file
include ("$settingspath/config.inc");

#
# this defines getpostvars()
include('getpostvars.inc');

# let's set up our database connection
include ("$settingspath/database.inc");

# the wrapper I wrote to help with database calls
include ('keyvalue.inc');

?>
