<?php
# this include prints the database error code and message after an insert
#
print "<br>The query was: \"INSERT INTO $table ($fields) VALUES ($values)\"<br>\n";
print "<br>The return code from the query was <b>" . mysql_errno($link) . ": \"" . mysql_error($link) . " \n</b><br>\n";
?>
