<?php
# include file that sets up our database connection
#
# here we set up our database connection and perhaps define a few things

################################################################################################
#                                      I M P O R T A N T                                       #
#                                                                                              #
# You need to put this file OUTSIDE of the webserver's search path.                            #
# For instance, put the file in /home/username/, instead of /home/username/public_html.        #
# Failure to do this simple step will place your password where crackers can easily get to it. #
#                                                                                              #
#                                  YOU HAVE BEEN WARNED!!!!                                    #
#                                                                                              #
################################################################################################

$mysql_server = 'localhost';
$username     = 'username';
$password     = 'password';
$database     = 'invoices';
#

$link = mysql_connect ($mysql_server, $username, $password)
  or die ("Could not connect to $mysql_server");
#print ("<small>Connected successfully to the database running on <b>$mysql_server</b>.</small><p>");
mysql_select_db($database,$link);

?>
