<?php
print "<b>settings/config.inc is being included</b><br>\n";
# this file is meant to act as a central place to store constants.
#
# sales taxes
define("TAX_RATE",        "10");
$tax_rate         = 10;   # this is a percentage
# does your local government require you to collect sales taxes on your labor, in addition to materials?
# possible values: 0, 1 or 2
# a value of
#   '0' means that labor is never taxed under any circumstances
#   '1' means that labor is always taxed
#   '2' means that labor is sometimes taxed: labor is taxed only when any material (hardware) appears on the invoice
define("IS_LABOR_TAXED",  "2");
$is_labor_taxed   = 1;
#
?>
