<?php
# Here we are trying to list all of the invoices sent to a particular company

# Our boilerplate include file
include ('standardinclude.inc');

###############################################################################################
#                                       print header                                          #
###############################################################################################

$title  = 'List Invoices By Company';
include("$settingspath/header.inc");

?>

<h1 align="center">Welcome to WebInvoicer</h1>

<center><a href="http://joeykelly.net/scratchpad/index.cgi?WebInvoicer">Developer's wiki</a></center>
